/*
** Module   : P2JField.java
** Abstract : Container for DMO field definitions.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 SVL 20130624 Created initial version.
*/

package com.goldencode.p2j.persist;

import com.goldencode.p2j.util.*;

/**
 * Container for DMO field definitions.
 */
public class P2JField
{
   /** Field name. */
   private String name;

   /** Field type. */
   private String type;

   /** Extent size. */
   private long extent;

   /** Field format. */
   private String format;

   /** Initial field value. */
   private BaseDataType initial;

   /** Field label. */
   private String label;

   /** Column label. */
   private String columnLabel;

   /**
    * Convenience constructor.
    * @param name
    *        Field name.
    * @param type
    *        Field type.
    * @param extent
    *        Extent size.
    * @param format
    *        Field format.
    * @param initial
    *        Initial value.
    * @param label
    *        Field label.
    * @param columnLabel
    *        Column label.
    */
   public P2JField(String name,
                   String type,
                   long extent,
                   String format,
                   BaseDataType initial,
                   String label,
                   String columnLabel)
   {
      this.name = name;
      this.type = type;
      this.extent = extent;
      this.format = format;
      this.initial = initial;
      this.label = label;
      this.columnLabel = columnLabel;
   }

   /**
    * Get field name.
    *
    * @return  field name.
    */
   public String getName()
   {
      return name;
   }

   /**
    * Get field type.
    *
    * @return  field type.
    */
   public String getType()
   {
      return type;
   }

   /**
    * Get extent size.
    *
    * @return  extent size.
    */
   public long getExtent()
   {
      return extent;
   }

   /**
    * Get field format.
    *
    * @return  field format.
    */
   public String getFormat()
   {
      return format;
   }

   /**
    * Get initial value.
    *
    * @return  initial value.
    */
   public BaseDataType getInitial()
   {
      return initial;
   }

   /**
    * Get field label.
    *
    * @return  field label.
    */
   public String getLabel()
   {
      return label;
   }

   /**
    * Get column label.
    *
    * @return  column label.
    */
   public String getColumnLabel()
   {
      return columnLabel;
   }
}